list_word_abb = set(["gdđt",
                     "pctpmt",
                     "sđnđ",
                     "cnht",
                     "mttqvn",
                     "đhclc",
                     "ks",
                     "ytế",
                     "pcthtl",
                     "kst",
                     "nhnnvn",
                     "hsgqt",
                     "ndtv",
                     "dnnvv",
                     "tn-mt",
                     "gplx",
                     "khcn",
                     "tcmn",
                     "tntt",
                     "dvtt",
                     "qcdccs",
                     "pkl",
                     "hvnclc",
                     "csvn",
                     "qbv",
                     "tttm",
                     "pnvn",
                     "hđtt",
                     "pclbtư",
                     "tnhh",
                     "vhgdttnnđ",
                     "ctn",
                     "lct",
                     "pccn",
                     "qp",
                     "dtnn",
                     "hvannd",
                     "thvn",
                     "hvnh",
                     "shnn",
                     "vnd",
                     "gcnqsdđơ",
                     "plvn",
                     "vnn",
                     "hqhp",
                     "dnvn",
                     "hkvn",
                     "hđt",
                     "cntt",
                     "gcmnd",
                     "hvkhqs",
                     "khktnnmn",
                     "hdv",
                     "dhs",
                     "dhktcn",
                     "nhnt",
                     "qlhc",
                     "gd",
                     "hq",
                     "bcđts",
                     "bhl",
                     "hđnd",
                     "kdcn",
                     "nsx",
                     "ktv",
                     "đd",
                     "cntn",
                     "hmnđ",
                     "đkđt",
                     "csđn",
                     "xs",
                     "pcc",
                     "btv",
                     "ttvgt",
                     "hdnd",
                     "bhnn",
                     "ksnd",
                     "lllđ",
                     "ndcm",
                     "qsmt",
                     "qbv",
                     "tbmmn",
                     "tctt",
                     "lntt",
                     "bvmt",
                     "tpdn",
                     "sgtvt",
                     "uvbct",
                     "pcmt",
                     "pcgdbth",
                     "tnxk",
                     "xdntm",
                     "gstskh",
                     "hđcd",
                     "plvn",
                     "đkvn",
                     "đhbkhcm",
                     "lđtbxh",
                     "qcgnhh",
                     "gdgt",
                     "ttdh",
                     "đkdt",
                     "xklđ",
                     "qckdtxd",
                     "csnd",
                     "pcgdthcs",
                     "sx",
                     "tnk",
                     "ptt",
                     "nmld",
                     "ttvn",
                     "ccb",
                     "chqs",
                     "csdc",
                     "xs",
                     "ttytdp",
                     "kt-xh",
                     "hđcdgsnn",
                     "tmdv",
                     "tthtsv",
                     "sdđnn",
                     "gt",
                     "ub",
                     "ngnd",
                     "bđn",
                     "nđ",
                     "bxh",
                     "ptnt",
                     "cđsp",
                     "tpcn",
                     "hnv",
                     "hngđ",
                     "sgd",
                     "đtv",
                     "bchcd",
                     "thpt",
                     "hđtđ",
                     "pghh",
                     "bhtn",
                     "gplhđb",
                     "cs",
                     "lđbđvn",
                     "tcttmsg",
                     "hkvn",
                     "đhbkhn",
                     "nhtmcp",
                     "tbnn",
                     "nst",
                     "ttkttv",
                     "qh-kt",
                     "đtla",
                     "tcvn",
                     "tpcp",
                     "khkd",
                     "tddc",
                     "tctn",
                     "cshs",
                     "tpo",
                     "tdv",
                     "attt",
                     "atvstp",
                     "lntt",
                     "csmt",
                     "gt-vt",
                     "đcs",
                     "thgt",
                     "tnxh",
                     "bcđt",
                     "bnhv",
                     "bchtw",
                     "nx",
                     "qcvn",
                     "dnt",
                     "hsgqg",
                     "ktnt",
                     "gdpt",
                     "mttq",
                     "bs",
                     "vsattp",
                     "tcbvntd",
                     "ttxvn",
                     "đt",
                     "ktnt",
                     "ttbđs",
                     "đhhvn",
                     "thqg",
                     "atnđ",
                     "vksnd",
                     "bgd",
                     "nhtmnn",
                     "hcvl",
                     "pcccr",
                     "phhs",
                     "đbtsxb",
                     "gcn",
                     "tckt",
                     "tttv",
                     "ttdvvl",
                     "dvvl",
                     "vpcc",
                     "tpcp",
                     "tb-xh",
                     "gdcd",
                     "qp",
                     "blv",
                     "hcv",
                     "tth",
                     "gcnkqt",
                     "tnmt",
                     "nls",
                     "bctn",
                     "pctt",
                     "ptth",
                     "rlc",
                     "pclbtw",
                     "kcn",
                     "bnhv",
                     "dnbh",
                     "ttnn",
                     "kd",
                     "vphc",
                     "cktg",
                     "nxbgd",
                     "sggpo",
                     "bhnn",
                     "csđttpmt",
                     "bts",
                     "ktx",
                     "sbt",
                     "bctc",
                     "nn-ptnt",
                     "lđbđ",
                     "ss",
                     "ktqd",
                     "sxkd",
                     "nnvn",
                     "gcnqshnơ",
                     "đhktcn",
                     "chxhcn",
                     "qsdđ",
                     "cnht",
                     "vlxd",
                     "kkt",
                     "btbnn",
                     "hl",
                     "bltths",
                     "gptm",
                     "hlqg",
                     "hđcdgs",
                     "hhhv",
                     "pcccr",
                     "kts",
                     "syll",
                     "đhđd",
                     "ktxh",
                     "mtv",
                     "đbtn",
                     "đhgtvt",
                     "tskh",
                     "hđkt",
                     "tchl",
                     "dn",
                     "pclb",
                     "nqd",
                     "ghz",
                     "ptnn",
                     "cccd",
                     "bqt",
                     "qltt",
                     "nhđa",
                     "km/h",
                     "gcnđkkd",
                     "cnv",
                     "tvv",
                     "cbtt",
                     "cnqsdđ",
                     "đkxt",
                     "cbpg",
                     "tx",
                     "hssv",
                     "đkvđ",
                     "gdpt",
                     "lltp",
                     "nhnnptnt",
                     "dl",
                     "đhnt",
                     "cbpg",
                     "stt",
                     "tchq",
                     "tcs",
                     "ttđm",
                     "hn",
                     "bvđk",
                     "tt-tt",
                     "pgs",
                     "bcc",
                     "qt",
                     "tno",
                     "đhbc",
                     "ndt",
                     "km/h",
                     "gđtla",
                     "đkhk",
                     "nnt",
                     "qsd",
                     "đhdl",
                     "cqđt",
                     "ktnn",
                     "csg",
                     "tctd",
                     "ubmttqvn",
                     "vltk",
                     "đcsvn",
                     "shtd",
                     "btvh",
                     "ttkttv",
                     "gdkhq",
                     "lmlm",
                     "hsmt",
                     "cmcn",
                     "qk",
                     "vtv",
                     "qcvn",
                     "đhbk",
                     "nsnn",
                     "hđts",
                     "ptv",
                     "ndvn",
                     "tkcn",
                     "gdnn",
                     "bđs",
                     "hvbcvt",
                     "csmt",
                     "tvn",
                     "gdđh",
                     "ttgt",
                     "xhtt",
                     "pttm",
                     "lhtnvn",
                     "đhkh",
                     "nvh",
                     "gcq",
                     "hvcnbcvt",
                     "tnnt",
                     "tbtt",
                     "pl",
                     "atgt",
                     "hnd",
                     "nncnc",
                     "tbnn",
                     "kđcl",
                     "ckqt",
                     "hđlđ",
                     "kk",
                     "sbt",
                     "đvttn",
                     "đtnn",
                     "đkkh",
                     "tg",
                     "gtgd",
                     "tbt",
                     "đhqghn",
                     "bk",
                     "đhđcqt",
                     "pctpcnc",
                     "gdcd",
                     "mxh",
                     "ttatxh",
                     "pgđ",
                     "ctck",
                     "hsd",
                     "bgdđt",
                     "hđct",
                     "csđt",
                     "hs-sv",
                     "ct",
                     "ptcs",
                     "pgs-ts",
                     "gsts",
                     "gs.ts",
                     "bhtg",
                     "ttbyt",
                     "đta",
                     "tnđt",
                     "tctn",
                     "gcnsk",
                     "kqkd",
                     "t.ư",
                     "gđtt",
                     "ctrl",
                     "gv",
                     "ntbd",
                     "nvhtn",
                     "kcn-kcx",
                     "pccc",
                     "gpnk",
                     "hqđt",
                     "gs-ts",
                     "xdcb",
                     "cstt",
                     "vhtt",
                     "tđbkvn",
                     "vh-tt-dl",
                     "ttks",
                     "cskv",
                     "kdc",
                     "tcn",
                     "bhtn",
                     "vbqppl",
                     "ktstq",
                     "tsn",
                     "svđ",
                     "ltqđtd",
                     "tcvsg",
                     "cspctpmt",
                     "vpcp",
                     "gdkhq",
                     "mbh",
                     "bchqs",
                     "csvc",
                     "ttck",
                     "tpdn",
                     "nhm",
                     "blhs",
                     "ghpgvn",
                     "gsht",
                     "lltp",
                     "đhqg",
                     "cmt",
                     "xskt",
                     "nx",
                     "pctn",
                     "lhpnvn",
                     "nhcthp",
                     "cv",
                     "vthkcc",
                     "hsđkdt",
                     "lđ",
                     "nlđ",
                     "dtts",
                     "đvưt",
                     "vpqh",
                     "ts-bs",
                     "gcnqsh",
                     "vhttdl",
                     "pbgdpl",
                     "vqg",
                     "llvtnd",
                     "ptn",
                     "đhcđ",
                     "nsưt",
                     "qncn",
                     "hđba",
                     "vh-tt",
                     "sv–hs",
                     "ttcn",
                     "bvtv",
                     "thads",
                     "tntp",
                     "kdhđc",
                     "cscđ",
                     "ttct",
                     "đhktqd",
                     "cnvc",
                     "xdhk",
                     "bltths",
                     "pmh",
                     "csb",
                     "bpck",
                     "qbltd",
                     "gcnqsdđ",
                     "qhtd",
                     "kt-xh",
                     "mtqg",
                     "bqt",
                     "p/v",
                     "qckt",
                     "ntnn",
                     "bctn",
                     "qg",
                     "bcs",
                     "đttx",
                     "klđt",
                     "đtqg",
                     "mg/kg",
                     "nxbvhtt",
                     "cđ",
                     "bn",
                     "vpcc",
                     "kcnc",
                     "gdvn",
                     "tphcm",
                     "tp.hcm",
                     "hđndtp",
                     "xh",
                     "nckh",
                     "bst",
                     "pcthcs",
                     "ktcn",
                     "vsattp",
                     "ykvn",
                     "ctclqg",
                     "hlttqg",
                     "lđlđ",
                     "nhctcn",
                     "cp",
                     "cahn",
                     "gdtx",
                     "ttgdck",
                     "cssx",
                     "cvpm",
                     "hhhv",
                     "vnch",
                     "anđt",
                     "dtht",
                     "dntn",
                     "khđt",
                     "mxh",
                     "ttdh",
                     "nvqs",
                     "đhcn",
                     "đbp",
                     "qs",
                     "antg",
                     "tmcp",
                     "ctch",
                     "tgpl",
                     "cchc",
                     "ubmttq",
                     "tnv",
                     "svvn",
                     "chdc",
                     "hsdt",
                     "đhkt",
                     "bcvt",
                     "gđđh",
                     "bhtg",
                     "ptdtnt",
                     "ttth",
                     "đthvn",
                     "cnkt",
                     "đmn",
                     "xnc",
                     "pclb",
                     "kh-cn",
                     "csqlhc",
                     "tt",
                     "cbccvc",
                     "tacn",
                     "annd",
                     "bhxh",
                     "kcx",
                     "hv",
                     "pk-kq",
                     "hkddvn",
                     "ttxh",
                     "vh-tt-dl",
                     "cpttt",
                     "khlcnt",
                     "pk-kq",
                     "csdl",
                     "qchq",
                     "vksndtc",
                     "lb",
                     "nn",
                     "cpsxtm",
                     "tmdv",
                     "sv",
                     "xđgn",
                     "bcđđmđh",
                     "pnvn",
                     "qld",
                     "thcb",
                     "ttdv",
                     "thdl",
                     "cđv",
                     "nhđtpt",
                     "nhtmqd",
                     "qsmt",
                     "qt",
                     "ttbdvh",
                     "lnst",
                     "mtth",
                     "ubnd",
                     "nkt",
                     "gt-vt",
                     "gs",
                     "tbktsg",
                     "ncc",
                     "gp",
                     "đvtn",
                     "đtlt",
                     "rlcd",
                     "tthc",
                     "kcn-kcx",
                     "stk",
                     "thktsmđ",
                     "mtqg",
                     "mtth",
                     "pct",
                     "csxh",
                     "tand",
                     "tthc",
                     "ctcc",
                     "kđtntl",
                     "nsut",
                     "nmđ",
                     "pcth",
                     "ttks",
                     "nknv",
                     "sg",
                     "gmd",
                     "svhs",
                     "kv3",
                     "tcmr",
                     "vnm",
                     "dnvvn",
                     "vđ",
                     "qpan",
                     "cntt-tt",
                     "dvmtr",
                     "stk",
                     "nlmt",
                     "tncs",
                     "vpqh",
                     "cmcn",
                     "nkkn",
                     "ts",
                     "đhkhtn",
                     "catw",
                     "sđh",
                     "tdtt",
                     "spkt",
                     "kttt",
                     "pctpmt",
                     "kv1",
                     "svđv",
                     "vnđ",
                     "pcgd",
                     "đhđn",
                     "nđt",
                     "hcm",
                     "hđcdgscs",
                     "vbqppl",
                     "bp",
                     "ctcn",
                     "ndtv",
                     "nkbv",
                     "gcnqsd",
                     "sxh",
                     "mg/kg",
                     "vđqg",
                     "dvtmcm",
                     "pgd",
                     "hd",
                     "hctc",
                     "hs",
                     "sđtla",
                     "ctđl",
                     "hkhktvn",
                     "đtqg",
                     "vsmt",
                     "ktstq",
                     "dvmtr",
                     "khktnn",
                     "nv",
                     "atttgt",
                     "qtdnd",
                     "hkqt",
                     "tnsvvn",
                     "vh-tt",
                     "tnvn",
                     "bcđpctntư",
                     "nsx",
                     "tct",
                     "hđnd",
                     "hkqt",
                     "ttqlkt",
                     "đkkd",
                     "htxnn",
                     "ttgdtx",
                     "chqs",
                     "thkts",
                     "nmld",
                     "ttxd",
                     "pgs-ts",
                     "nxbkhxh",
                     "nsut",
                     "hnht",
                     "kntc",
                     "nhtw",
                     "qđ",
                     "tddc",
                     "gvcn",
                     "kđt",
                     "ubtvqh",
                     "hđnt",
                     "gs-ts",
                     "ubtdtt",
                     "htxdvnn",
                     "qh",
                     "ndcm",
                     "uvbch",
                     "gstt",
                     "sbd",
                     "bhyt",
                     "tttv",
                     "hsd",
                     "đtvhd",
                     "pttt",
                     "vphc",
                     "tmn",
                     "pctp",
                     "tnđh",
                     "kdnpn",
                     "đhsp",
                     "vac",
                     "kddv",
                     "qh-kt",
                     "tcdl",
                     "khkths",
                     "kđtm",
                     "hđqt",
                     "attp",
                     "tntn",
                     "xttm",
                     "hđ",
                     "klqg",
                     "dqtv",
                     "tncn",
                     "cncn",
                     "tngt",
                     "đhkhtnhn",
                     "ctđ",
                     "chdcnd",
                     "htx",
                     "xdntm",
                     "chkqt",
                     "nđvn",
                     "đna",
                     "dd",
                     "hđcdgsn",
                     "gdvn",
                     "lđtb",
                     "tndn",
                     "bcs",
                     "catp",
                     "đhct",
                     "qppl",
                     "hmtn",
                     "bpck",
                     "tns",
                     "khtn",
                     "lhpnvn",
                     "nncđdc",
                     "smđh",
                     "kđs",
                     "bqp",
                     "bs",
                     "ubndtp",
                     "khxh",
                     "cnch",
                     "cskh",
                     "vhnt",
                     "dtqg",
                     "pmh",
                     "nxbtn",
                     "kđclgd",
                     "tgđ",
                     "cbtt",
                     "hktt",
                     "lnst",
                     "bchtư",
                     "tvqh",
                     "bbt",
                     "bhnt",
                     "tnsv",
                     "hsmt",
                     "br-vt",
                     "nvqs",
                     "ctth",
                     "nhtư",
                     "thx",
                     "đvht",
                     "cnxh",
                     "gb",
                     "lhtn",
                     "ths",
                     "bct",
                     "cbcnv",
                     "gdck",
                     "tnnd",
                     "đhhb",
                     "nltt",
                     "ghz",
                     "hlv",
                     "pcgdth",
                     "ttyt",
                     "ttđb",
                     "nsnd",
                     "dtts",
                     "hmtn",
                     "ttatgt",
                     "pctnxh",
                     "nnptnt",
                     "kcx-kcn",
                     "tbn",
                     "tw",
                     "bcđ",
                     "vnch",
                     "xhcn",
                     "ksndtc",
                     "vks",
                     "dagtđt",
                     "khls",
                     "ttvh",
                     "bot",
                     "blttds",
                     "qncn",
                     "pv",
                     "tbxh",
                     "kv2",
                     "dcch",
                     "xdll",
                     "pgs.ts",
                     "tnt",
                     "nctt",
                     "blv",
                     "annd",
                     "hhvn",
                     "tbn",
                     "npp",
                     "ktxh",
                     "cskt",
                     "đk",
                     "hsbc",
                     "qđnd",
                     "cpxd",
                     "utgt",
                     "clb",
                     "pt-th",
                     "pcbltkcn",
                     "xnk",
                     "mtđt",
                     "pbgdpl",
                     "tbktvn",
                     "vđvqg",
                     "lhq",
                     "xdll",
                     "chxhcn",
                     "hcđ",
                     "vhttdl",
                     "nn-ptnt",
                     "đhbktphcm",
                     "ll",
                     "tpct",
                     "vsmt",
                     "hhtg",
                     "lts",
                     "thcs",
                     "kcb",
                     "nhtm",
                     "htcđ",
                     "gvtn",
                     "shtt",
                     "m/s",
                     "ck",
                     "cand",
                     "stt",
                     "csb",
                     "th.s",
                     "lsq",
                     "tsdđ",
                     "blds",
                     "ubdt",
                     "bxl",
                     "nxbqđnd",
                     "ttbvqtg",
                     "ncl",
                     "tp",
                     "lhp",
                     "nhctvn",
                     "nv2",
                     "đtđ",
                     "gđt",
                     "gtvt",
                     "lhs",
                     "cbnv",
                     "blttds",
                     "llvtnd",
                     "cnch",
                     "csgt",
                     "ndvn",
                     "gvth",
                     "ttn",
                     "gtcc",
                     "m/s",
                     "tnkq",
                     "hđh",
                     "sđt",
                     "gpmb",
                     "blds",
                     "vpđd",
                     "ttk",
                     "đbscl",
                     "nv3",
                     "đtb",
                     "tckh",
                     "tcct",
                     "hspt",
                     "nhm",
                     "chkqt",
                     "cbnv",
                     "sđk",
                     "tvhk",
                     "tnxp",
                     "hkdd",
                     "ttttn",
                     "bđvn",
                     "ktm",
                     "tđc",
                     "bl",
                     "qlhc",
                     "ntk",
                     "tandtc",
                     "bhnt",
                     "slna",
                     "cbqlgd",
                     "pclbmn",
                     "hb",
                     "sxkd",
                     "tmđt",
                     "nhcsxh",
                     "lhpn",
                     "bl",
                     "thcsnđ",
                     "ms",
                     "pcbth",
                     "vck",
                     "tnhc",
                     "htxnn",
                     "chlb",
                     "anqg",
                     "đtvn",
                     "hvch",
                     "pccn",
                     "đcstq",
                     "cptd",
                     "gs-tskh",
                     "qtdnd",
                     "xnc",
                     "llvt",
                     "pcmt",
                     "ubkt",
                     "ntts",
                     "cn",
                     "cstt",
                     "bqp",
                     "nn & ptnt",
                     "nn&ptnt",
                     "antq",
                     "thcn",
                     "đná",
                     "tnln",
                     "cttc",
                     "chnd",
                     "kh-đt",
                     "anct",
                     "bgk",
                     "mtxt",
                     "ntnn",
                     "tcnn",
                     "bks",
                     "thtt",
                     "qppl",
                     "kqkd",
                     "antv",
                     "tdttqg",
                     "qlđt",
                     "mhz",
                     "bql",
                     "gtgt",
                     "dtnn",
                     "qs",
                     "tn-mt",
                     "qcdc",
                     "tto",
                     "ptnn",
                     "tccn",
                     "tcct",
                     "csđttp",
                     "ntts",
                     "cnxh",
                     "nn&ptnt",
                     "ptdtnt",
                     "ksv",
                     "đbdt",
                     "bqlda",
                     "hagl",
                     "dnnn",
                     "snn",
                     "hctl",
                     "btc",
                     "tpcđ",
                     "kttt",
                     "vđv",
                     "đb",
                     "ktqdhn",
                     "skhcn",
                     "bhđc",
                     "đh",
                     "khlcnt",
                     "thads",
                     "hđđg",
                     "gdck",
                     "svtn",
                     "ncs",
                     "cph",
                     "đsq",
                     "kcx-kcn",
                     "ngnd",
                     "cttt",
                     "bx",
                     "sgk",
                     "cspk",
                     "nhđt",
                     "dqtv",
                     "cbcs",
                     "gsht",
                     "bvmt",
                     "tbd",
                     "tccs",
                     "tthtcđ",
                     "ttdd",
                     "ntd",
                     "xhh",
                     "ddvn",
                     "ttxd",
                     "skss",
                     "gtnt",
                     "hlbđ",
                     "gtmt",
                     "vthkcc",
                     "nv1",
                     "dv",
                     "pcthtl",
                     "nncnc",
                     "kdn",
                     "ttton",
                     "hsdt",
                     "gdmn",
                     "đttxqm",
                     "tttt",
                     "lts",
                     "tt-tt",
                     "bgh",
                     "hđđb",
                     "skhcnmt",
                     "vp",
                     "bch",
                     "kttv",
                     "nnt",
                     "ytdp",
                     "bbcvt",
                     "antv",
                     "pctp",
                     "kbnn",
                     "htx",
                     "khkt",
                     "ls",
                     "ctsn",
                     "bv",
                     "cbcc",
                     "ttbdvhng",
                     "gtgd",
                     "đtxdcb",
                     "hvn",
                     "ttlt",
                     "cđdc",
                     "cmnd",
                     "cmt",
                     "bctc",
                     "vhgdtntn",
                     "nhđá",
                     "đhktcn",
                     "mhx",
                     "gpxd",
                     "ckqt",
                     "pkl",
                     "tq",
                     "đhkhxh",
                     "kwh",
                     "dnnvv",
                     "bxh",
                     "hvncl",
                     "ttcp",
                     "csnd",
                     "gdmn",
                     "ts-bs",
                     "đhn",
                     "skhđt",
                     "lmlm",
                     "sggp",
                     "cbccvc",
                     "hcb",
                     "hphn",
                     "cccd",
                     "tntt",
                     "bh",
                     "đc",
                     "hđxx",
                     "đtdđ",
                     "dnbh",
                     "cnh",
                     "ctcp",
                     "nhnn",
                     "cttnhh",
                     "nxb",
                     "gđ",
                     "kcnc",
                     "đbqh",
                     "khkthn",
                     "tsvm",
                     "ctv",
                     "gvg",
                     "csđtlx",
                     "cnsh",
                     "pcbl",
                     "ctrl",
                     "sgtt",
                     "cntt-tt",
                     "kh-cn",
                     "sdđ",
                     "tttt",
                     "svnckh",
                     "gs-tskh",
                     "ưcv",
                     "hsv",
                     "xhtt",
                     "qtkd",
                     "bcđqg",
                     "hsg",
                     "hkhkt",
                     "ubcknn",
                     "kdl",
                     "pgd",
                     "đrl",
                     "gvmn",
                     "htnd",
                     "gcnqshn",
                     "kdđv",
                     "cq",
                     "ctxh",
                     "qlda",
                     "bđ"])
